import board, digitalio, time, random
from typing import Optional

class FurbyCompound:
    """
    These are silly moves. Compound moves.
    """

    def ambulance(self, cycles: int = 50):
        for i in range(cycles):
            self.green_pin.value = True
            self.red_pin.value = False
            time.sleep(0.2)
            self.green_pin.value = False
            self.red_pin.value = True
            time.sleep(0.2)
        self.green_pin.value = False
        self.red_pin.value = False

    # Mixed ================================================================

    def bark(self):
        self.wait_until_bitten()
        self.red_pin.value = True
        self.say('woof')
        for i in range(20):
            self.green_pin.value = True
            self.red_pin.value = True
            time.sleep(0.05)
            self.green_pin.value = False
            self.red_pin.value = False
            time.sleep(0.05)
        self.complete_revolution()

    ## Motor based.

    def flutter(self, cycles: int=5):
        """
        Flutters eye lids

        :param cycles:
        :return:
        """
        self.set_percent_speed(70)
        for i in range(cycles):
            for action in (self.move_clockwise, self.move_counterclockwise):
                action()
                time.sleep(0.2)
                self.wait_until_revolution()
                time.sleep(0.2)
        self.halt()

    def fall_asleep(self):
        """
        Mimics falling asleep (does not shutdown)

        :return:
        """
        self.complete_revolution(70)
        self.halt()
        self.set_percent_speed(55)
        self.move_clockwise()
        time.sleep(5)
        self.halt()
        original_volume = self.volume
        original_rate = self.rate
        self.volume = 0.1
        self.rate = 50
        self.say('zed zed zed', move=False)
        time.sleep(1)
        self.say('zed zed zed', move=False)
        time.sleep(1)
        self.say('zed zed zed', move=False)
        self.volume = original_volume
        self.rate = original_rate

    def shut_eyes(self, quickly=False):
        self.complete_revolution(70)
        if quickly:
            speed = 100
            tock = 1.2
        else:
            speed = 70
            tock = 2
        self.set_percent_speed(speed)
        self.move_clockwise()
        time.sleep(tock)
        self.halt()

    def dance(self, speed:Optional[float]=None, cycles:int=10):
        """
        Moves randomly.

        :param speed:
        :param cycles:
        :return:
        """
        if speed:
            self.set_percent_speed(speed)
        self.complete_revolution()
        for i in range(cycles):
            tempo = random.random()
            self.move_counterclockwise()
            time.sleep(tempo)
            self.move_clockwise()
            time.sleep(tempo)
        self.halt()

    def blink(self, cycles:int=10):
        """
        Blinks. Inverse of flutter. Note that depending on power it may overshoot as it's the
        opposite side of the rotation pin.

        :param cycles:
        :return:
        """
        self.shut_eyes(quickly=True)
        self.set_percent_speed(100)
        for i in range(cycles):
            for action in (self.move_clockwise, self.move_counterclockwise):
                action()
                time.sleep(0.6)
        self.halt()


# SpeechRecognition
import speech_recognition as sr
import pyaudio, time, wave

class ToldFurby:
    speech_recogniser = sr.Recognizer()


    def listen(self,
               format: int = pyaudio.paInt32,
               chunk:int= 4096,
               rate:int = 16000,
               temp_filename:str = 'temp.wav'):
        """
        Uses the speech_recognition module.
        However, due to the

        :param format:
        :param chunk:
        :param rate:
        :param temp_filename:
        :return:
        """

        # set up stream
        p = pyaudio.PyAudio()
        stream = p.open(format=format,
                        channels=2,
                        rate=rate,
                        input=True,
                        frames_per_buffer=chunk)
        # record
        frames = []
        tock = time.time()
        try:
            while not self.squeezed or time.time() - tock < 2:
                frames.append(stream.read(chunk))
        except: # it whistles otherwise
            stream.stop_stream()
            stream.close()
        stream.stop_stream()
        stream.close()
        p.terminate()
        # save
        wf = wave.open(temp_filename, 'wb')
        wf.setnchannels(2)
        wf.setsampwidth(p.get_sample_size(format))
        wf.setframerate(rate)
        wf.writeframes(b''.join(frames))
        wf.close()
        # read and convert
        with sr.AudioFile('temp.wav') as source:
            audio = self.speech_recogniser.record(source)
        return self.speech_recogniser.recognize_google(audio)

    def _resolve_command(self, cmd, *args, **kwargs):
        getattr(self, cmd)(*args, **kwargs)

    def fill_keywords(self):
        self.keywords = {'hello': lambda decree: self.say("Hello"),
                         'execute': self.excute,
                         'pretty': lambda decree: self.flutter(),
                         'your name': lambda decree: self.say("My name is Furby")
                         }

    def be_told(self):
        # listen speech to text.
        # ????
        decree = self.listen()
        for keyword, action in self.keywords.items:
            if all([word in decree for word in keyword.split()]):
                action(decree)

    def excute(self, degree):
        commands = degree.split('execute')[1].strip().split()
        # ...


import pyttsx3
import os
import time

class FurbyTalk:
    def __init__(self, voice_name: str, voice_volume: int, voice_rate: int):
        self.engine = pyttsx3.init('espeak', debug=True)
        self.volume = voice_volume
        self.engine.setProperty('voice', voice_name)
        self.engine.setProperty('rate', voice_rate)

    def say(self, text):
        """
        convert the ``text`` to speech and play it.

        * To say in a different language change ``voice_name``
        * To say in a different volume change ``voice_volume`` (0-1)
        * To say in a different rate change ``voice_rate` (200 is default).

        This gets overwitten.

        :param text: text to say
        :return:
        """
        self.engine.say(text)
        self.engine.runAndWait()

    def _get_volume(self):
        """
        :return: volume of speech
        """
        return self.engine.getProperty('volume')

    def _set_volume(self, volume: float):
        assert 1. >= volume >= 0.
        self.engine.setProperty('volume', volume)

    volume = property(_get_volume, _set_volume)

    def _get_rate(self):
        """
        :return: rate of speech
        """
        return self.engine.getProperty('rate')

    def _set_rate(self, rate: float):
        self.engine.setProperty('rate', rate)

    rate = property(_get_rate, _set_rate)

    def recite_ip(self):
        self.say("My local IP address is")
        time.sleep(0.2)
        ip = os.popen('hostname -I').read().strip()
        for octet in ip.replace('.', ' dot ').split(' '):
            self.say(octet)
            time.sleep(0.3)



from mpu6050 import mpu6050

class FurbyGyro:
    """
    If the gyroscope were level, the re
    """
    resting_x = -5.547365246582031
    resting_y = -0.5051765502929687
    resting_z = -8.099584216308592

    def __init__(self):
        self.gyro = mpu6050(0x68)

    def define_static(self):
        """
        The furby is level and not moving, while earth gravity is still the same.
        The board is not z axis pointing to zenith, but at an angle
        :return:
        """
        acc = self.gyro.get_accel_data()
        self.resting_x = acc['x']
        self.resting_y = acc['y']
        self.resting_z = acc['z']

    def calculate_translation_matrix(self, vector):
        """
        One day I will write this.
        :return:
        """
        return vector

    @property
    def speed(self):
        """
        :return: how fast is it going? (velocity)
        """
        # technically multiplied by transformation matrix
        return self.calculate_translation_matrix(self.gyro.get_gyro_data())

    @property
    def acceleration(self):
        """
        :return: how fast is it speeding up? (acceleration)
        """
        # technically multiplied by transformation matrix
        return self.calculate_translation_matrix(self.gyro.get_accel_data())

    @property
    def temperature(self):
        """
        :return: temperature in Celcius
        """
        return self.gyro.get_temp()

    def is_lifted(self):
        """
        :return: true when lifted
        """
        return abs(self.speed['z']) > 10

    def is_moved(self):
        """
        :return: true when moved
        """
        return abs(self.speed['x']) > 10 or abs(self.speed['y']) > 10

    @property
    def lifted(self):
        """
        :return: lifted?
        """
        return self.is_lifted()

    @property
    def moved(self):
        """
        :return: moved?
        """
        return self.is_moved()

    def wait_until_moved(self):
        """
        Idle until moved
        """
        while not self.is_lifted() and not self.is_moved():
            pass







import board, digitalio, time


class FurbyButtons:
    """
    There are a few buttons. All configured as pull-ups
    """

    def __init__(self, red: int, green: int, mouth: int, chest: int, back: int):
        # LEDs
        self.red_pin = digitalio.DigitalInOut(digitalio.Pin(red))  #: red pin LED
        self.green_pin = digitalio.DigitalInOut(digitalio.Pin(green)) #: green pin LED
        for color_pin in (self.red_pin, self.green_pin):
            color_pin.switch_to_output(False)
        # buttons
        self.mouth_pin = digitalio.DigitalInOut(digitalio.Pin(mouth))  #: mouth pin trigger "bitten"
        self.chest_pin = digitalio.DigitalInOut(digitalio.Pin(chest))  #: chest pin trigger: "fore_squeezed"/"squeezed"
        self.back_pin = digitalio.DigitalInOut(digitalio.Pin(back))  #: back pin trigger: "aft_squeezed"/"squeezed"
        for button_pin in (self.mouth_pin, self.chest_pin, self.back_pin):
            button_pin.switch_to_input(pull=digitalio.Pull.UP)

    @property
    def bitten(self) -> bool:
        """
        True when self.mouth_pin.value is not 1

        :return: is the furby mouth pressed?
        """
        return not self.mouth_pin.value

    @property
    def fore_squeezed(self) -> bool:
        """
        True when self.chest_pin.value is not 1

        :return: is the furby chest squeezed?
        """
        return not self.chest_pin.value

    @property
    def aft_squeezed(self) -> bool:
        """
        True when self.back_pin.value is not 1

        :return: is the furby back squeezed?
        """
        return not self.back_pin.value

    @property
    def squeezed(self) -> bool:
        """
        True when self.chest_pin.value or self.back_pin.value is not 1

        :return: is the furby chest or back squeezed?
        """
        return self.fore_squeezed or self.aft_squeezed

    # === Waits ==============================

    def wait_until_squeezed(self):
        """
        Hold until the furby is squeezed
        """
        while not self.squeezed:
            pass

    def wait_until_bitten(self):
        """
        Hold until the furby has its mouth pressed
        """
        while not self.bitten:
            pass



from typing import get_type_hints
import pydoc


class RestlessFurby: # restful...

    def _resolve_request(self, cmd):
        """
        Restful API Mode.
        This action is trigged when any route that is not home is requested

        :param cmd:
        :return:
        """
        try:
            from flask import Flask, request
            kwargs = request.args
            print(f'Request {cmd}: {kwargs} from {request.remote_addr}')
            getattr(self, cmd)(**kwargs)
            return {'status': 'OK'}
        except Exception as error:
            return {'status': 'error',
                    'error': f'{error.__class__.__name__}: {error}'}


    def _home(self):
        """
        Restful API Mode.
        This action is trigged when home is requested.
        """
        reply = '## Furby Restful API options\n\n'
        reply += 'To trigger a command, say `furby.yell`, use 198.162.1/0.xx:1998/yell?text=I%20hate%20you ' +\
                 'where xx is the furby\'s netword address\n'
        reply += 'Namely, the route (part before the question mark) is the command, and its arguments are ' +\
                  'key=value separated by an ampersand (that is a URL query).\n' +\
                  'Using Pythod requests, just submit it as a dictionary\n'
        for k in [k for k in dir(self) if k.find('_') != 0]:
            attribute = getattr(self, k)
            reply += f'###{k}\n>{get_type_hints(attribute)}\n{pydoc.getdoc(attribute)}\n\n'
        return reply

    def restful(self):
        """
        The furby listens on port 1998, the year the Furby was introduced (Nawww).
        Note that it is using Flask's internal app serving method, so is not suitable for use over the internet...
        :return:
        """
        from flask import Flask
        import waitress
        app = Flask(__name__)
        app.add_url_rule('/<cmd>', 'command', self._resolve_request)
        app.add_url_rule('/', 'home', self._home)
        waitress.serve(app, port=1998, host='0.0.0.0')



#!/usr/bin/env python

import digitalio, board, pulseio
from typing import Optional

class FurbyMotor:
    """
    TB6612 motor driver and sensor to control cycles (pull-up)
    """
    high_speed = 0xffff

    def __init__(self, pwma: int, stby: int, ain1: int, ain2: int, cycle: int):
        # standby: H-bridges to work when high
        self.standby_pin = digitalio.DigitalInOut(digitalio.Pin(stby))  #: standy pin for TB6612
        self.standby_pin.switch_to_output(False)
        # direction 1
        self.ain1_pin = digitalio.DigitalInOut(digitalio.Pin(ain1))   #: Ain1 pin for TB6612
        self.ain1_pin.switch_to_output(False)
        # direction 2
        self.ain2_pin = digitalio.DigitalInOut(digitalio.Pin(ain2))     #: Ain2 pin for TB6612
        self.ain2_pin.switch_to_output(False)
        # pwma
        self.pwm_pin = pulseio.PWMOut(pin=digitalio.Pin(pwma),
                                      duty_cycle=0,
                                      frequency=100)     #: pwm pin for TB6612
        # cycle pin
        self.cycle_pin = digitalio.DigitalInOut(digitalio.Pin(cycle))  #: is the cycle complete trigger pin (back of furby)
        self.cycle_pin.switch_to_input(pull=digitalio.Pull.UP)

    def move_clockwise(self):
        """
        Start moving fubry clockwise.
        """
        self.standby_pin.value = True
        self.pwm_pin.duty_cycle = self.high_speed
        self.ain1_pin.value = True
        self.ain2_pin.value = False

    def move_counterclockwise(self):
        """
        Start moving fubry counter-clockwise.
        """
        self.standby_pin.value = True
        self.pwm_pin.duty_cycle = self.high_speed
        self.ain1_pin.value = False
        self.ain2_pin.value = True

    def halt(self):
        """
        Stop motion.
        """
        self.standby_pin.value = False
        self.pwm_pin.duty_cycle = 0
        self.ain1_pin.value = False
        self.ain2_pin.value = False

    def inverse(self):
        if self.ain1_pin.value:
            self.move_counterclockwise()
        elif self.ain2_pin.value:
            self.move_clockwise()
        else: # halted
            pass

    def get_percent_speed(self):
        return self.high_speed * 100 / 0xffff

    def set_percent_speed(self, speed: int):
        """
        Will convert to high_speed hex (``0xffff``)
        :param speed: speed of motor as %.
        :return:
        """
        self.high_speed = int(speed/100 * 0xffff)
        if self.ain1_pin.value or self.ain2_pin.value:
            self.pwm_pin.duty_cycle = self.high_speed

    percent_speed = property(get_percent_speed, set_percent_speed)

    def wait_until_revolution(self):
        """
        Idle until the motors complete a revolution/cycle (back trigger)
        """
        while self.cycle_pin.value:
            pass

    def complete_revolution(self, speed: Optional[int]=None):
        """
        Move and wait until the motors complete a revolution/cycle
        :param speed:
        :return:
        """
        if speed:
            self.set_percent_speed(speed)
        self.move_counterclockwise()
        self.wait_until_revolution()
        self.halt()



import threading
from typing import *

class BackFurby:

    def background(self, command: Union[str, Callable], *args, **kwargs):
        """
        Run a command in the background.
        It is a fake-overloaded function where command is either a str (name of method to be called)
        or a method to be called.

        >>> furby.background('ambulance', 10)

        or

        >>> furby.background(furby.ambulance, 10)

        :param command: method
        :param args:
        :param kwargs:
        :return:
        """
        if isinstance(command, str):
            command = getattr(self, command)
        thread = threading.Thread(target=command, args=args, kwargs=kwargs).start()
        return thread



from typing import Any

class TemporaryValue:
    """
    context manager for a temporary value.

    >>> TemporaryValue.furby = furby
    >>> with TemporaryValue('red', True):
    >>>      pass

    The furby bound ``use_temporarily`` knows furby

    >>> with furby.use_temporarily('red', True):
    >>>       pass
    """
    _furby = None

    def __init__(self, attribute_name: str, value: Any):
        assert attribute_name in ('volume', 'rate', 'speed', 'red', 'green')
        self.attribute_name = attribute_name
        self.temporary = value
        self.original = self.get()

    def get(self):
        if self.attribute_name == 'volume':
            return self._furby.volume  # this is not a typo
        elif self.attribute_name == 'rate':
            return self._furby.rate
        elif self.attribute_name == 'speed':
            return self._furby.percent_speed
        elif self.attribute_name == 'red':
            return self._furby.red_pin.value
        elif self.attribute_name == 'green':
            return self._furby.green_pin.value
        else:
            raise ValueError(f'Unknown attribute name {self.attribute_name}')

    def set(self, value):
        if self.attribute_name == 'volume':
            self._furby.volume = value
        elif self.attribute_name == 'rate':
            self._furby.rate = value
        elif self.attribute_name == 'speed':
            self._furby.percent_speed = value
        elif self.attribute_name == 'red':
            self._furby.red_pin.value = value
        elif self.attribute_name == 'green':
            self._furby.green_pin.value = value
        else:
            raise ValueError(f'Unknown attribute name {self.attribute_name}')

    def __enter__(self):
        self.set(self.temporary)

    def __exit__(self, *args):
        self.set(self.original)



"""
FurbyMotor adds motor control

SoundMotor controls motor by sound

"""

from .buttons import FurbyButtons
from .motor import FurbyMotor
from .talk import FurbyTalk
from .sound import FurbySound
from .gyro import FurbyGyro
from .restless import RestlessFurby
from .background import BackFurby
from .compound_moves import FurbyCompound  # more like silly actions
from .temporary import TemporaryValue
from .tests import TestFurby

import time
from typing import Optional, Callable, Dict


class Furby(FurbyMotor,
            FurbyButtons,
            FurbyTalk,
            BackFurby,
            FurbySound,
            FurbyCompound,
            FurbyGyro,
            RestlessFurby,
            TestFurby):
    """
    Control a Furby with Python and a pi!

    :ivar acceleration: gyroscope
    :vartype acceleration: dict
    :ivar aft_squeezed: is the back squeezed?
    :vartype aft_squeezed: bool
    :ivar ain1_pin: H-bridge for motor
    :vartype ain1_pin: DigitalInOut
    :ivar ain2_pin: H-bridge for motor
    :vartype ain2_pin: DigitalInOut
    :ivar back_pin: back button (input digitalio.Pull.UP)
    :vartype back_pin: DigitalInOut
    :ivar bitten: is it bitting down?
    :vartype bitten: bool
    :ivar chest_pin: chest button (input digitalio.Pull.UP)
    :vartype chest_pin: DigitalInOut
    :ivar cycle_pin: cycle button (input digitalio.Pull.UP)
    :vartype cycle_pin: DigitalInOut
    :ivar engine: espeak engine
    :vartype engine: Engine
    :ivar fore_squeezed: is back squeezed?
    :vartype fore_squeezed: bool
    :ivar green_pin: forehead green
    :vartype green_pin: DigitalInOut
    :ivar gyro: The gyroscope obkect
    :vartype gyro: mpu6050
    :ivar high_speed: hex value. See percent_speed
    :vartype high_speed: int
    :ivar lifted:
    :vartype lifted: bool
    :ivar mouth_pin:
    :vartype mouth_pin: DigitalInOut
    :ivar moved:
    :vartype moved: bool
    :ivar permitted_actions:
    :vartype permitted_actions: list
    :ivar playing:
    :vartype playing: bool
    :ivar pwm_pin:
    :vartype pwm_pin: PWMOut
    :ivar rate:
    :vartype rate: int
    :ivar red_pin:
    :vartype red_pin: DigitalInOut
    :ivar resting_x:
    :vartype resting_x: float
    :ivar resting_y:
    :vartype resting_y: float
    :ivar resting_z:
    :vartype resting_z: float
    :ivar soundcard_status_file:
    :vartype soundcard_status_file: str
    :ivar speed:
    :vartype speed: dict
    :ivar squeezed:
    :vartype squeezed: bool
    :ivar standby_pin:
    :vartype standby_pin: DigitalInOut
    :ivar temperature:
    :vartype temperature: float
    :ivar volume:
    :vartype volume: float
    """

    def __init__(self,
                 pwma: int = 22,  # motor driver speed - white
                 stby: int = 4,  # motor driver on
                 ain1: int = 27,  # motor driver forward
                 ain2: int = 17,  # motor driver reverse
                 cycle: int = 12,  # revolution button (pull-up input)
                 red: int = 14,  # red LED (output)
                 green: int = 24,  # green LED (output)
                 mouth: int = 15,  # mouth button (pull-up input)
                 chest: int = 16,  # chest button (pull-up input)
                 back: int = 26,  # back button (pull-up input)
                 voice_name: str = 'en-scottish+m4',  # espeak/pyttsx3
                 voice_volume: int = 0.7,  # espeak/pyttsx3
                 voice_rate: int = 200):  # espeak/pyttsx3
        FurbyMotor.__init__(self, pwma=pwma, stby=stby, ain1=ain1, ain2=ain2, cycle=cycle)
        FurbyButtons.__init__(self, red=red, green=green, mouth=mouth, chest=chest, back=back)
        FurbyTalk.__init__(self, voice_name=voice_name, voice_rate=voice_rate, voice_volume=voice_volume)
        FurbyGyro.__init__(self)
        # FurbySound, BackFurby and FurbyTests no init.
        TemporaryValue.furby = self
        self.use_temporarily = TemporaryValue

    def move_on_play(self):
        """
        This is for playing sound -not via say/yell.

        Holds forever.
        """
        while True:
            if self.playing:
                self.move_clockwise()
            else:
                self.halt()
            time.sleep(0.1)

    def say(self, text: str, move: bool = True):
        """
        convert the ``text`` to speech and play it.

        * To say in a different language change ``voice_name``
        * To say in a different volume change ``voice_volume`` (0-1)
        * To say in a different rate change ``voice_rate` (200 is default).

        :param text: text to say
        :param move: move while talking
        :return:
        """
        if move:
            self.move_clockwise()
            for phrase in text.replace(',','.').split('.'):
                super().say(phrase)
                self.inverse()
                time.sleep(0.1)
            self.halt()
        else:
            super().say(text)

    def yell(self, text):
        """
        ``say`` but at full volume.
        With red led for drama.

        :param text:
        :return:
        """
        original_volume = self.volume
        original_speed = self.high_speed
        # max
        self.set_percent_speed(100)
        self.red_pin.value = True
        self.volume = 1.
        self.say(text)
        self.high_speed = original_speed
        self.volume = original_volume
        self.red_pin.value = False

    permitted_actions = ['lifted', 'moved', 'bitten', 'squeezed', 'aft_squeezed', 'fore_squeezed']

    def action_cycle(self, actions: Dict[str, Callable]):
        """
        This runs a single cycle
        Given a dictionary of actions, where the key is an trigger (past particle, e.g. ``bitten``)
        and vale is a function to be called if the trigger is true.

        :param actions: dictionary of trigger name --> action function to call
        :return:
        """
        for trigger_name, action in actions.items():
            if trigger_name in self.permitted_actions and getattr(self, trigger_name):
                action()

    def loop_actions(self, actions: Dict[str, Callable]):
        """
        Runs on loop the method ``action_cycle``.
        Namely, given a dictionary of actions, where the key is an trigger (past particle, e.g. ``bitten``)
        and vale is a function to be called if the trigger is true.

        :param actions: dictionary of trigger name --> action function to call
        :return:
        """
        while True:
            self.action_cycle(actions)



class FurbySound:

    soundcard_status_file = '/proc/asound/card0/pcm0p/sub0/status'

    @property
    def playing(self):
        """
        :return: Is the sound card in use?
        """
        with open(self.soundcard_status_file, 'r') as fh:
            value = fh.read()
        if value == 'RUNNING':
            return True
        else:  # 'closed'
            return False


class TestFurby:
    def tests(self):
        """
        Run diagnostic tests. requires human action.
        :return:
        """
        for button_name, trigger_name in [('mouth', 'bitten'),
                                          ('chest', 'fore_squeezed'),
                                          ('back', 'aft_squeezed')]:
            if getattr(self, trigger_name):
                self.say(f'Error, {button_name} button is reported pressed!')
                continue
            self.say(f'please press {button_name} button')
            while not getattr(self, trigger_name):
                pass
            self.say('thank you')
        self.say(f'please lift me up')
        self.wait_until_moved()
        self.say('thank you')
        self.background(self.ambulance, 10)
        self.say('I am blinking my forehead')



from setuptools import setup, find_packages
import os
here = os.path.abspath(os.path.dirname(__file__))

from warnings import warn
import platform

if platform.uname().machine != 'armv6l':
    warn('This can only be installed on a Raspberry Pi Zero')

requires = [
    'Flask',
    'Adafruit-Blinka', # circuitpython: 'board', 'digitalio', 'pulseio'
    'mpu6050-raspberrypi', #gyro
    'pyttsx3',
    #'smbus'
]

long_description = open(os.path.join(here, 'README.md')).read()

# ============================

setup(
    name='pyfurby',
    version='0.1',
    packages=find_packages(),
    url='https://github.com/matteoferla/pyfurby',
    license='MIT',
    author='matteoferla',
    author_email='matteo.ferla@gmail.com',
    description='Controlling the various parts of the Furby with Python and a Pi Zero',
    long_description=long_description,
    install_requires=requires
)
